/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.twa.xliff.handler;

import java.io.File;
import java.io.IOException;
import java.net.URL;

import junit.framework.TestCase;

import org.eclipse.core.runtime.FileLocator;
import org.xml.sax.SAXException;

import benten.core.io.Files;
import benten.twa.ui.jobs.AbstractWorkflowFileHandler;
import benten.twa.xliff.status.BentenExtractXliffFragmentStatus;

public class ExtractXliffFragmentHandlerTest extends TestCase {

	private final AbstractWorkflowFileHandler target = new ExtractXliffFragmentHandler();
	private String dataPath;

	private void setDataPath(String caseId) throws IOException {
		final String dataDir = "/src/" + getClass().getName().replace('.', '/') + "Data/" + caseId + "/";
		final URL dataUrl = getClass().getClassLoader().getResource(dataDir);
		dataPath = FileLocator.resolve(dataUrl).getPath();
	}

	private void assertEqualsFile(String actualFileName, String expectedFileName) throws IOException {
		final File actualFile = new File(dataPath + actualFileName);
		final File expectedFile = new File(dataPath + expectedFileName);
		assertEquals(Files.readFileToString(expectedFile), Files.readFileToString(actualFile));
	}

	//-------------------------------------------------------------------------

	public void testRun() throws IOException, SAXException {
		try {
			target.run(null);
			fail();
		} catch (final NullPointerException e) {
			assertTrue(true);
		}
	}

	public void testRun0001() throws IOException, SAXException {
		setDataPath("0001");

		final BentenExtractXliffFragmentStatus status = new BentenExtractXliffFragmentStatus();
		status.setFromXliffFile(new File(dataPath + "in/test.html.xlf"));
		status.setToDir(new File(dataPath + "out"));
		status.setIncludeDate(false);
		status.setSizeLimit(10);
		status.setState("x-reviewed");

		target.run(status);

		assertEqualsFile("out/test.html-1.xlf", "out/expected.html-1.xlf");
		assertEqualsFile("out/test.html-2.xlf", "out/expected.html-2.xlf");
	}
}
