/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.ui;

import java.io.File;
import java.io.IOException;
import java.net.URL;

import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * Benten UI プラグインの基底クラス。
 * @author KASHIHARA Shinji
 */
public abstract class AbstractBentenUiPlugin extends AbstractUIPlugin {

	/** デバッグ・フラグ */
	public static final boolean IS_DEBUG = Boolean.valueOf(System.getProperty("benten.debug")); //$NON-NLS-1$

	/**
	 * プラグイン id の取得。
	 * @return プラグイン id
	 */
	public String getPluginId() {
		return getClass().getPackage().getName();
	}

	/**
	 * 指定されたメッセージのログ出力。
	 * @param message ログ出力するメッセージ
	 */
	public void log(Object message) {
		if (message instanceof Throwable) {
			final Throwable e = (Throwable) message;
			getLog().log(new Status(IStatus.WARNING, getPluginId(), -1, e.toString(), e));
			if (IS_DEBUG) {
				e.printStackTrace();
			}
			Display.getDefault().asyncExec(new Runnable() {
				public void run() {
					final UiStatus s = new UiStatus(IStatus.ERROR, e.getMessage(), e);
					UiPlugin.openDialog("エラーが発生しました", s);
				}
			});
		} else {
			final String s = message == null ? "" : message.toString(); //$NON-NLS-1$
			getLog().log(new Status(IStatus.WARNING, getPluginId(), s));
			if (IS_DEBUG) {
				System.out.println(message);
			}
		}
	}

	/**
	 * このプラグイン配下のファイルを取得。
	 * @param path パス
	 * @return ファイル。存在しない場合やアクセスできない場合は null。
	 */
	public File getFile(String path) {
		try {
			final URL entry = getBundle().getEntry(path);
			return new File(FileLocator.resolve(entry).getPath());
		} catch (final IOException e) {
			log(e);
			return null;
		}
	}

	/**
	 * イメージの取得。
	 * @param path パス
	 * @return イメージ
	 */
	public Image getImage(String path) {
		Image image = getImageRegistry().get(path);
		if (image == null) {
			final ImageDescriptor descriptor = imageDescriptorFromPlugin(getPluginId(), path);
			if (descriptor != null) {
				getImageRegistry().put(path, image = descriptor.createImage());
			}
		}
		return image;
	}
}
