/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.ui.preference;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ProjectScope;
import org.eclipse.core.runtime.preferences.IScopeContext;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.preferences.ScopedPreferenceStore;

import benten.ui.UiPlugin;

/**
 * Benten プロジェクト・プロパティー定義クラス。
 * @author KASHIHARA Shinji
 */
public class BentenProjectProperty {

	/** プロジェクト・プロパティー保管キー */
	public static enum ProjectProperty {
		TRANS_TARGET_ID, TRANS_TARGET_IMPORT_FROM_DIR, TRANS_TARGET_IMPORTED, PROMPT_TRANS_TARGET_IMPORTED, XLIFF_CONVERTED, PROMPT_XLIFF_CONVERTED
	}

	/**
	 * プロジェクトのプロパティー・ストアを取得。
	 * @param project プロジェクト
	 * @return プロジェクトのプロパティー・ストア
	 */
	public static IPreferenceStore getStore(IProject project) {
		final String PLUGIN_ID = UiPlugin.class.getPackage().getName();
		return new RealtimeSavedPreferenceStore(new ProjectScope(project), PLUGIN_ID);
	}

	/**
	 * 値をセットしたときに、すぐに永続化するストア・クラス。
	 */
	private static class RealtimeSavedPreferenceStore extends ScopedPreferenceStore {

		public RealtimeSavedPreferenceStore(IScopeContext context, String qualifier) {
			super(context, qualifier);
		}

		@Override
		public void setValue(String name, boolean value) {
			super.setValue(name, value);
			saveQuietly();
		}

		@Override
		public void setValue(String name, String value) {
			super.setValue(name, value);
			saveQuietly();
		}

		public void saveQuietly() {
			Display.getDefault().asyncExec(new Runnable() {
				public void run() {
					try {
						save();
					} catch (final Exception e) {
						UiPlugin.getDefault().log(e);
					}
				}
			});
		}
	}
}
